@@ -690,14 +690,18 @@ defSurv <- function(dtDefs = NULL,
     switch(newdist,
       binary = {
         .isValidArithmeticFormula(newform, defVars)
-        .isIdLogit(link)
+        .isIdLogLogit(link)
       },
-      beta = ,
-      binomial = {
+      beta = {
         .isValidArithmeticFormula(newform, defVars)
         .isValidArithmeticFormula(variance, defVars)
         .isIdLogit(link)
       },
+      binomial = {
+        .isValidArithmeticFormula(newform, defVars)
+        .isValidArithmeticFormula(variance, defVars)
+        .isIdLogLogit(link)
+      },
       noZeroPoisson = ,
       poisson = ,
       exponential = {
@@ -905,6 +909,16 @@ defSurv <- function(dtDefs = NULL,
   invisible(link)
 }
 
+#' Is identity, log, logit?
+#'
+#' @param link link as string.
+#' @return Invisible, error if link not valid.
+#' @noRd
+.isIdLogLogit <- function(link) {
+  .isLink(link, c("identity", "log", "logit"))
+  invisible(link)
+}
+
 #' Error template for link check
 #'
 #' @param link Link as string.
