@@ -960,6 +960,7 @@ genSpline <- function(dt, newvar, predictor, theta,
 #' @param keepEvents Indicator to retain original "events" columns. Defaults
 #' to FALSE.
 #' @param idName Name of id field in existing data set.
+#' @param envir Optional environment, defaults to current calling environment.
 #' @return Original data table with survival time
 #' @examples
 #' # Baseline data definitions
@@ -996,7 +997,7 @@ genSpline <- function(dt, newvar, predictor, theta,
 #
 genSurv <- function(dtName, survDefs, digits = 3, 
   timeName = NULL, censorName = NULL, eventName = "event", 
-  typeName = "type", keepEvents = FALSE, idName = "id") {
+  typeName = "type", keepEvents = FALSE, idName = "id", envir = parent.frame()) {
   
   # For double-dot notation
   
@@ -1042,13 +1043,13 @@ genSurv <- function(dtName, survDefs, digits = 3,
     subDef <- survDefs[varname == events[i]]
 
     formshape <- subDef[1, shape]
-    shape <- as.vector(.evalWith(formshape, .parseDotVars(formshape,  envir = parent.frame()), dtSurv))
+    shape <- as.vector(.evalWith(formshape, .parseDotVars(formshape,  envir = parent.frame()), dtSurv, envir = envir))
 
     formscale <- subDef[1, scale]
-    scale <- as.vector(.evalWith(formscale, .parseDotVars(formscale, envir = parent.frame()), dtSurv))
+    scale <- as.vector(.evalWith(formscale, .parseDotVars(formscale, envir = parent.frame()), dtSurv, envir = envir))
     
     formulas <- subDef[, formula]
-    form1 <- as.vector(.evalWith(formulas[1], .parseDotVars(formulas[1], envir = parent.frame()), dtSurv))
+    form1 <- as.vector(.evalWith(formulas[1], .parseDotVars(formulas[1], envir = parent.frame()), dtSurv, envir = envir))
     
     if (nrow(subDef) > 1) {
       
@@ -1063,7 +1064,7 @@ genSurv <- function(dtName, survDefs, digits = 3,
       transition <- subDef[2, transition]
       t_adj <- transition ^ (1/shape)
      
-      form2 <- as.vector(.evalWith(formulas[2], .parseDotVars(formulas[2], envir = parent.frame()), dtSurv))
+      form2 <- as.vector(.evalWith(formulas[2], .parseDotVars(formulas[2], envir = parent.frame()), dtSurv, envir = envir))
       
       threshold <- exp(form1) * t_adj
       period <- 1*(nlogu < threshold) + 2*(nlogu >= threshold)
@@ -1175,3 +1176,34 @@ genSynthetic <- function(dtFrom, n = nrow(dtFrom),
   
 }
 
+#' @title Generate data from a density defined by a vector of integers
+#' @description Data are generated from an a density defined by a vector of integers
+#' @param n Number of samples to draw from the density.
+#' @param dataDist Vector that defines the desired density
+#' @param varname Name of variable name
+#' @param uselimits Indicator to use minimum and maximum of input data vector as 
+#' limits for sampling. Defaults to FALSE, in which case a smoothed density that
+#' extends beyond the limits is used.
+#' @param id A string specifying the field that serves as the record id. The
+#' default field is "id".
+#' @return A data table with the generated data
+#' @examples
+#' data_dist <- data_dist <- c(1, 2, 2, 3, 4, 4, 4, 5, 6, 6, 7, 7, 7, 8, 9, 10, 10)
+#' 
+#' genDataDensity(500, data_dist, varname = "x1", id = "id")
+#' genDataDensity(500, data_dist, varname = "x1", uselimits = TRUE, id = "id")
+#' @export
+#' @concept generate_data
+
+genDataDensity <- function(n, dataDist, varname, uselimits = FALSE, id = "id") {
+  
+  assertNotMissing(n = missing(n), dataDist = missing(dataDist), varname = missing(varname))
+  
+  dataDist <- round(dataDist, 0)
+
+  .dd <- genData(n, id = id)
+  addDataDensity(.dd, dataDist, varname, uselimits)[]
+  
+}
+
+
