@@ -123,10 +123,11 @@ test_that("'uniformInt' formula checked correctly", {
 # .genmixture ----
 test_that("mixtures are generated correctly", {
   skip_on_cran()
-  def <- defData(varname = "a", formula = 5)
+  def <- defData(varname = "a", formula = 10)
   def <- defData(def,
     varname = "blksize",
-    formula = "..sizes[1] | .5 + ..sizes[2] * a/10 | .5", dist = "mixture"
+    formula = "..sizes[1] | .5 + ..sizes[2] * a/10 | .5", 
+    dist = "mixture"
   )
   sizes <- c(2, 4)
   env <- environment()
